Summary: A shell similar to ksh, but with improvements.
Name: zsh
Version: 4.0.4
Release: 3
License: IBM_ILA
Group: System Environment/Shells
Source0: ftp://ftp.rge.com/pub/shells/zsh/zsh/zsh-%{version}.tar.bz2
Source1: ftp://ftp.rge.com/pub/shells/zsh/zsh/zsh-%{version}-doc.tar.bz2
Source2: IBM_ILA
Patch0: zsh-%{version}-boolcodes.patch
URL: http://www.zsh.org
Prereq: coreutils grep /sbin/install-info
Buildroot: /var/tmp/%{name}-root
%define DEFCC cc

%description
The zsh shell is a command interpreter usable as an interactive login shell and
as a shell script command processor.  Zsh resembles the ksh shell (the Korn
shell), but includes many enhancements.  Zsh supports command line editing,
built-in spelling correction, programmable command completion, shell functions
(with autoloading), a history mechanism and more.

%prep
%setup -q -b 1
%patch0 -p1 -b .boolcodes

# Put License into place
cat $RPM_SOURCE_DIR/IBM_ILA LICENCE > LICENSE

%build
# Use the default compiler for this platform - gcc otherwise
if [[ -z "$CC" ]]
then
    if test "X`type %{DEFCC} 2>/dev/null`" != 'X'; then
       export CC=%{DEFCC}
    else
       export CC=gcc
    fi
fi
if test "X$CC" != "Xgcc"
then
       export RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS | sed 's:-fsigned-char::'`
       export CFLAGS="$RPM_OPT_FLAGS"
fi

# XXX replace the following with GNUconfigure
autoconf
./configure --prefix=%{_prefix} --enable-etcdir=/etc

# We don't want this defined;  grep it out of the config.h.
perl -pi -e "s|\#define HAVE_CAP_GET_PROC.*$||" config.h

make

%install
rm -rf ${RPM_BUILD_ROOT}
mkdir -p ${RPM_BUILD_ROOT}%{_prefix}/info ${RPM_BUILD_ROOT}/etc

make prefix=${RPM_BUILD_ROOT}%{_prefix} install install.info

/usr/bin/strip ${RPM_BUILD_ROOT}%{_prefix}/bin/zsh || :
chmod 755 ${RPM_BUILD_ROOT}%{_prefix}/bin/zsh
gzip -9nf ${RPM_BUILD_ROOT}%{_prefix}/info/zsh*
for file in BUGS FAQ CONTRIBUTORS FEATURES NEWS
do
    cp Etc/$file .
done

# Fix shell magic pathnames
for FNAME in Util/helpfiles Functions/Example/cat Functions/Misc/checkmail \
             Functions/Misc/run-help
do
    sed -e 's#/usr/local/bin/zsh#/usr/bin/zsh#g' $FNAME \
     > %{_tmppath}/sed_out.$$ && mv %{_tmppath}/sed_out.$$ $FNAME
done

(cd $RPM_BUILD_ROOT
 for dir in bin lib share
 do
    mkdir -p usr/$dir
    cd usr/$dir
    ln -sf ../..%{_prefix}/$dir/* .
    cd -
 done
)

%clean
rm -rf ${RPM_BUILD_ROOT}

%post
/sbin/install-info %{_prefix}/info/zsh.info.gz %{_prefix}/info/dir \
	--entry="* zsh: (zsh).			An enhanced bourne shell."

%preun
if [ "$1" = 0 ] ; then
    /sbin/install-info --delete %{_prefix}/info/zsh.info.gz %{_prefix}/info/dir \
	--entry="* zsh: (zsh).			An enhanced bourne shell."
fi



%files
%defattr(-,root,system)
%doc BUGS CONTRIBUTORS ChangeLog FAQ FEATURES META-FAQ NEWS README LICENSE
%doc Etc Util Functions Doc/*.html Doc/*.ps Doc/*.dvi
%{_prefix}/bin/zsh
%{_prefix}/bin/zsh-%{version}
%{_prefix}/lib/zsh
%{_prefix}/share/zsh
/usr/bin/zsh
/usr/bin/zsh-%{version}
/usr/lib/zsh
/usr/share/zsh
%{_prefix}/man/man1/*
%{_prefix}/info/zsh*

%changelog
* Mon Feb 21 2005 David Clissold <cliss@austin.ibm.com> 4.0.4-3
- Rebuilt to specify coreutils as a req (not fileutils).

* Fri Nov 22 2002 David Clissold <cliss@austin.ibm.com>
- Add IBM ILA license.

* Mon Oct 29 2001 David Clissold <cliss@austin.ibm.com>
- Update to version 4.0.4 (from 4.0.2).

* Fri Oct 27 2000 pkgmgr <pkgmgr@austin.ibm.com>
- Modify for AIX Freeware distribution

* Tue Mar  7 2000 Jeff Johnson <jbj@redhat.com>
- rebuild for sparc baud rates > 38400.

* Fri Mar 03 2000 Cristian Gafton <gafton@redhat.com>
- fix postun script so that we don't remove ourselves on every update
  doh...
- add a trigger to fix old versions of the package

* Mon Jan 31 2000 Cristian Gafton <gafton@redhat.com>
- rebuild to fix dependencies

* Thu Jan 13 2000 Jeff Johnson <jbj@redhat.com>
- update to 3.0.7.
- source /etc/profile so that USER gets set correctly (#5655).

* Fri Sep 24 1999 Michael K. Johnson <johnsonm@redhat.com>
- source /etc/profile.d/*.sh in zprofile

* Tue Sep 07 1999 Cristian Gafton <gafton@redhat.com>
- fix zshenv and zprofile scripts - foxed versions from HJLu.

* Thu Jul 29 1999 Bill Nottingham <notting@redhat.com>
- clean up init files some. (#4055)

* Tue May 18 1999 Jeff Johnson <jbj@redhat.com>
- Make sure that env variable TmpFile is evaluated. (#2898)

* Sun May  9 1999 Jeff Johnson <jbj@redhat.com>
- fix select timeval initialization (#2688).

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com>
- auto rebuild in the new build environment (release 10)
- fix the texi source
- patch to detect & link against nsl

* Wed Mar 10 1999 Cristian Gafton <gafton@redhat.com>
- use mktemp to handle temporary files.

* Thu Feb 11 1999 Michael Maher <mike@redhat.com>
- fixed bug #365

* Thu Dec 17 1998 Cristian Gafton <gafton@redhat.com>
- build for glibc 2.1

* Thu Sep 10 1998 Jeff Johnson <jbj@redhat.com>
- compile for 5.2

* Sat Jun 06 1998 Prospector System <bugs@redhat.com>
- translations modified for de

* Sat Jun  6 1998 Jeff Johnson <jbj@redhat.com>
- Eliminate incorrect info page removal.

* Fri May 08 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Sat Apr 11 1998 Cristian Gafton <gafton@redhat.com>
- manhattan build
- moved profile.d handling from zshrc to zprofile

* Wed Oct 21 1997 Cristian Gafton <gafton@redhat.com>
- Upgraded to 3.0.5
- Install-info handling

* Thu Jul 31 1997 Erik Troan <ewt@redhat.com>
- built against glibc

* Thu Apr 10 1997 Michael Fulbright <msf@redhat.com>
- Upgraded to 3.0.2
- Added 'reasonable' default startup files in /etc
